@@ -10,6 +10,7 @@ subsetofList <- function(x,l){
 }
 
 
+
 uniquePrim <- function(x)
   .Internal(unique(x, FALSE, FALSE))
 
@@ -22,6 +23,12 @@ setdiffPrim <- function (x, y)
     else x)
 }
 
+intersectPrim <- function (x, y) 
+{
+    y <- as.vector(y)
+    .Internal(unique( y[  .Internal(match( as.vector(x), y, 0, NULL))    ], FALSE, FALSE))
+}
+
 
 unlistPrim <- function(l, recursive=TRUE, use.names=TRUE)
   .Internal(unlist(l, recursive, use.names))
